User Configuration — PyRemoteData 0.0.16 documentation

# User Configuration

pyremotedata.config.ask_user(question, interactive=True)

pyremotedata.config.config_path()

pyremotedata.config.create_default_config(interactive=True)

pyremotedata.config.deparse_args(config, what)

pyremotedata.config.get_config()

pyremotedata.config.get_dataloader_config()

pyremotedata.config.get_implicit_mount_config()

pyremotedata.config.get_mount_config()

pyremotedata.config.get_this_config(this)

pyremotedata.config.remove_config()